# ionos-cloud-sdk
An enterprise-grade Infrastructure is provided as a Service (IaaS) solution that can be managed through a browser-based \"Data Center Designer\" (DCD) tool or via an easy to use API. 

The API allows you to perform a variety of management tasks such as spinning up additional servers, adding volumes, adjusting networking, and so forth. It is designed to allow users to leverage the same power and flexibility found within the DCD visual tool. Both tools are consistent with their concepts and lend well to making the experience smooth and intuitive.

This Python package is automatically generated by the [OpenAPI Generator](https://openapi-generator.tech) project:

- API version: 5.0
- Package version: 1.0.0
- Build package: org.openapitools.codegen.languages.PythonClientCodegen

## Requirements.

Python 2.7 and 3.4+

## Installation & Usage
### pip install

If the python package is hosted on a repository, you can install directly using:

```sh
pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git
```
(you may need to run `pip` with root permission: `sudo pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git`)

Then import the package:
```python
import ionos_cloud_sdk
```

### Setuptools

Install via [Setuptools](http://pypi.python.org/pypi/setuptools).

```sh
python setup.py install --user
```
(or `sudo python setup.py install` to install the package for all users)

Then import the package:
```python
import ionos_cloud_sdk
```

## Getting Started

Please follow the [installation procedure](#installation--usage) and then run the following:

```python
from __future__ import print_function

import time
import ionos_cloud_sdk
from ionos_cloud_sdk.rest import ApiException
from pprint import pprint

# Defining the host is optional and defaults to https://api.ionos.com/cloudapi/v5
# See configuration.py for a list of all supported configuration parameters.
configuration = ionos_cloud_sdk.Configuration(
    host = "https://api.ionos.com/cloudapi/v5"
)

# The client must configure the authentication and authorization parameters
# in accordance with the API server security policy.
# Examples for each auth method are provided below, use the example that
# satisfies your auth use case.

# Configure HTTP basic authorization: Basic Authentication
configuration = ionos_cloud_sdk.Configuration(
    username = 'YOUR_USERNAME',
    password = 'YOUR_PASSWORD'
)

# Configure API key authorization: Token Authentication
configuration = ionos_cloud_sdk.Configuration(
    host = "https://api.ionos.com/cloudapi/v5",
    api_key = {
        'Token Authentication': 'YOUR_API_KEY'
    }
)
# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['Token Authentication'] = 'Bearer'


# Enter a context with an instance of the API client
with ionos_cloud_sdk.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = ionos_cloud_sdk.BackupUnitApi(api_client)
    backupunit_id = 'backupunit_id_example' # str | The unique ID of the backup Unit
pretty = True # bool | Controls whether response is pretty-printed (with indentation and new lines) (optional) (default to True)
depth = 0 # int | Controls the details depth of response objects.  Eg. GET /datacenters/[ID]  - depth=0: only direct properties are included. Children (servers etc.) are not included  - depth=1: direct properties and children references are included  - depth=2: direct properties and children properties are included  - depth=3: direct properties and children properties and children's children are included  - depth=... and so on (optional) (default to 0)
x_contract_number = 56 # int | Users having more than 1 contract need to provide contract number, against which all API requests should be executed (optional)

    try:
        # Delete a Backup Unit
        api_response = api_instance.backupunits_delete(backupunit_id, pretty=pretty, depth=depth, x_contract_number=x_contract_number)
        pprint(api_response)
    except ApiException as e:
        print("Exception when calling BackupUnitApi->backupunits_delete: %s\n" % e)
    
```

## Documentation for API Endpoints

All URIs are relative to *https://api.ionos.com/cloudapi/v5*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*BackupUnitApi* | [**backupunits_delete**](docs/BackupUnitApi.md#backupunits_delete) | **DELETE** /backupunits/{backupunitId} | Delete a Backup Unit
*BackupUnitApi* | [**backupunits_find_by_id**](docs/BackupUnitApi.md#backupunits_find_by_id) | **GET** /backupunits/{backupunitId} | Returns the specified backup Unit
*BackupUnitApi* | [**backupunits_get**](docs/BackupUnitApi.md#backupunits_get) | **GET** /backupunits | List Backup Units 
*BackupUnitApi* | [**backupunits_patch**](docs/BackupUnitApi.md#backupunits_patch) | **PATCH** /backupunits/{backupunitId} | Partially modify a Backup Unit
*BackupUnitApi* | [**backupunits_post**](docs/BackupUnitApi.md#backupunits_post) | **POST** /backupunits | Create a Backup Unit
*BackupUnitApi* | [**backupunits_put**](docs/BackupUnitApi.md#backupunits_put) | **PUT** /backupunits/{backupunitId} | Modify a Backup Unit
*BackupUnitApi* | [**backupunits_ssourl_get**](docs/BackupUnitApi.md#backupunits_ssourl_get) | **GET** /backupunits/{backupunitId}/ssourl | Returns a single signon URL for the specified backup Unit.
*ContractApi* | [**contracts_get**](docs/ContractApi.md#contracts_get) | **GET** /contracts | Retrieve a Contract
*DataCenterApi* | [**datacenters_delete**](docs/DataCenterApi.md#datacenters_delete) | **DELETE** /datacenters/{datacenterId} | Delete a Data Center
*DataCenterApi* | [**datacenters_find_by_id**](docs/DataCenterApi.md#datacenters_find_by_id) | **GET** /datacenters/{datacenterId} | Retrieve a Data Center
*DataCenterApi* | [**datacenters_get**](docs/DataCenterApi.md#datacenters_get) | **GET** /datacenters | List Data Centers under your account
*DataCenterApi* | [**datacenters_patch**](docs/DataCenterApi.md#datacenters_patch) | **PATCH** /datacenters/{datacenterId} | Partially modify a Data Center
*DataCenterApi* | [**datacenters_post**](docs/DataCenterApi.md#datacenters_post) | **POST** /datacenters | Create a Data Center
*DataCenterApi* | [**datacenters_put**](docs/DataCenterApi.md#datacenters_put) | **PUT** /datacenters/{datacenterId} | Modify a Data Center
*IPBlocksApi* | [**ipblocks_delete**](docs/IPBlocksApi.md#ipblocks_delete) | **DELETE** /ipblocks/{ipblockId} | Delete IP Block
*IPBlocksApi* | [**ipblocks_find_by_id**](docs/IPBlocksApi.md#ipblocks_find_by_id) | **GET** /ipblocks/{ipblockId} | Retrieve an IP Block
*IPBlocksApi* | [**ipblocks_get**](docs/IPBlocksApi.md#ipblocks_get) | **GET** /ipblocks | List IP Blocks 
*IPBlocksApi* | [**ipblocks_patch**](docs/IPBlocksApi.md#ipblocks_patch) | **PATCH** /ipblocks/{ipblockId} | Partially modify IP Block
*IPBlocksApi* | [**ipblocks_post**](docs/IPBlocksApi.md#ipblocks_post) | **POST** /ipblocks | Reserve IP Block
*IPBlocksApi* | [**ipblocks_put**](docs/IPBlocksApi.md#ipblocks_put) | **PUT** /ipblocks/{ipblockId} | Modify IP Block
*ImageApi* | [**images_delete**](docs/ImageApi.md#images_delete) | **DELETE** /images/{imageId} | Delete an Image
*ImageApi* | [**images_find_by_id**](docs/ImageApi.md#images_find_by_id) | **GET** /images/{imageId} | Retrieve an Image
*ImageApi* | [**images_get**](docs/ImageApi.md#images_get) | **GET** /images | List Images 
*ImageApi* | [**images_patch**](docs/ImageApi.md#images_patch) | **PATCH** /images/{imageId} | Partially modify an Image
*ImageApi* | [**images_put**](docs/ImageApi.md#images_put) | **PUT** /images/{imageId} | Modify an Image
*KubernetesApi* | [**k8s_delete**](docs/KubernetesApi.md#k8s_delete) | **DELETE** /k8s/{k8sClusterId} | Delete Kubernetes Cluster
*KubernetesApi* | [**k8s_find_by_clusterid**](docs/KubernetesApi.md#k8s_find_by_clusterid) | **GET** /k8s/{k8sClusterId} | Retrieve Kubernetes Cluster
*KubernetesApi* | [**k8s_get**](docs/KubernetesApi.md#k8s_get) | **GET** /k8s | List Kubernetes Clusters
*KubernetesApi* | [**k8s_kubeconfig_get**](docs/KubernetesApi.md#k8s_kubeconfig_get) | **GET** /k8s/{k8sClusterId}/kubeconfig | Retrieve Kubernetes Configuration File
*KubernetesApi* | [**k8s_nodepools_delete**](docs/KubernetesApi.md#k8s_nodepools_delete) | **DELETE** /k8s/{k8sClusterId}/nodepools/{nodepoolId} | Delete Kubernetes Node Pool
*KubernetesApi* | [**k8s_nodepools_find_by_id**](docs/KubernetesApi.md#k8s_nodepools_find_by_id) | **GET** /k8s/{k8sClusterId}/nodepools/{nodepoolId} | Retrieve Kubernetes Node Pool
*KubernetesApi* | [**k8s_nodepools_get**](docs/KubernetesApi.md#k8s_nodepools_get) | **GET** /k8s/{k8sClusterId}/nodepools | List Kubernetes Node Pools
*KubernetesApi* | [**k8s_nodepools_nodes_delete**](docs/KubernetesApi.md#k8s_nodepools_nodes_delete) | **DELETE** /k8s/{k8sClusterId}/nodepools/{nodepoolId}/nodes/{nodeId} | Delete Kubernetes node
*KubernetesApi* | [**k8s_nodepools_nodes_find_by_id**](docs/KubernetesApi.md#k8s_nodepools_nodes_find_by_id) | **GET** /k8s/{k8sClusterId}/nodepools/{nodepoolId}/nodes/{nodeId} | Retrieve Kubernetes node
*KubernetesApi* | [**k8s_nodepools_nodes_get**](docs/KubernetesApi.md#k8s_nodepools_nodes_get) | **GET** /k8s/{k8sClusterId}/nodepools/{nodepoolId}/nodes | Retrieve Kubernetes nodes.
*KubernetesApi* | [**k8s_nodepools_nodes_replace_post**](docs/KubernetesApi.md#k8s_nodepools_nodes_replace_post) | **POST** /k8s/{k8sClusterId}/nodepools/{nodepoolId}/nodes/{nodeId}/replace | Recreate the Kubernetes node
*KubernetesApi* | [**k8s_nodepools_post**](docs/KubernetesApi.md#k8s_nodepools_post) | **POST** /k8s/{k8sClusterId}/nodepools | Create a Kubernetes Node Pool
*KubernetesApi* | [**k8s_nodepools_put**](docs/KubernetesApi.md#k8s_nodepools_put) | **PUT** /k8s/{k8sClusterId}/nodepools/{nodepoolId} | Modify Kubernetes Node Pool
*KubernetesApi* | [**k8s_post**](docs/KubernetesApi.md#k8s_post) | **POST** /k8s | Create Kubernetes Cluster
*KubernetesApi* | [**k8s_put**](docs/KubernetesApi.md#k8s_put) | **PUT** /k8s/{k8sClusterId} | Modify Kubernetes Cluster
*KubernetesApi* | [**k8s_versions_compatibilities_get**](docs/KubernetesApi.md#k8s_versions_compatibilities_get) | **GET** /k8s/versions/{clusterVersion}/compatibilities | Retrieves a list of available kubernetes versions for nodepools depending on the given kubernetes version running in the cluster.
*KubernetesApi* | [**k8s_versions_default_get**](docs/KubernetesApi.md#k8s_versions_default_get) | **GET** /k8s/versions/default | Retrieve the current default kubernetes version for clusters and nodepools.
*KubernetesApi* | [**k8s_versions_get**](docs/KubernetesApi.md#k8s_versions_get) | **GET** /k8s/versions | Retrieve available Kubernetes versions
*LabelApi* | [**datacenters_labels_delete**](docs/LabelApi.md#datacenters_labels_delete) | **DELETE** /datacenters/{datacenterId}/labels/{key} | Delete a Label from Data Center
*LabelApi* | [**datacenters_labels_find_by_key**](docs/LabelApi.md#datacenters_labels_find_by_key) | **GET** /datacenters/{datacenterId}/labels/{key} | Retrieve a Label of Data Center
*LabelApi* | [**datacenters_labels_get**](docs/LabelApi.md#datacenters_labels_get) | **GET** /datacenters/{datacenterId}/labels | List all Data Center Labels
*LabelApi* | [**datacenters_labels_post**](docs/LabelApi.md#datacenters_labels_post) | **POST** /datacenters/{datacenterId}/labels | Add a Label to Data Center
*LabelApi* | [**datacenters_labels_put**](docs/LabelApi.md#datacenters_labels_put) | **PUT** /datacenters/{datacenterId}/labels/{key} | Modify a Label of Data Center
*LabelApi* | [**datacenters_servers_labels_delete**](docs/LabelApi.md#datacenters_servers_labels_delete) | **DELETE** /datacenters/{datacenterId}/servers/{serverId}/labels/{key} | Delete a Label from Server
*LabelApi* | [**datacenters_servers_labels_find_by_key**](docs/LabelApi.md#datacenters_servers_labels_find_by_key) | **GET** /datacenters/{datacenterId}/servers/{serverId}/labels/{key} | Retrieve a Label of Server
*LabelApi* | [**datacenters_servers_labels_get**](docs/LabelApi.md#datacenters_servers_labels_get) | **GET** /datacenters/{datacenterId}/servers/{serverId}/labels | List all Server Labels
*LabelApi* | [**datacenters_servers_labels_post**](docs/LabelApi.md#datacenters_servers_labels_post) | **POST** /datacenters/{datacenterId}/servers/{serverId}/labels | Add a Label to Server
*LabelApi* | [**datacenters_servers_labels_put**](docs/LabelApi.md#datacenters_servers_labels_put) | **PUT** /datacenters/{datacenterId}/servers/{serverId}/labels/{key} | Modify a Label of Server
*LabelApi* | [**datacenters_volumes_labels_delete**](docs/LabelApi.md#datacenters_volumes_labels_delete) | **DELETE** /datacenters/{datacenterId}/volumes/{volumeId}/labels/{key} | Delete a Label from Volume
*LabelApi* | [**datacenters_volumes_labels_find_by_key**](docs/LabelApi.md#datacenters_volumes_labels_find_by_key) | **GET** /datacenters/{datacenterId}/volumes/{volumeId}/labels/{key} | Retrieve a Label of Volume
*LabelApi* | [**datacenters_volumes_labels_get**](docs/LabelApi.md#datacenters_volumes_labels_get) | **GET** /datacenters/{datacenterId}/volumes/{volumeId}/labels | List all Volume Labels
*LabelApi* | [**datacenters_volumes_labels_post**](docs/LabelApi.md#datacenters_volumes_labels_post) | **POST** /datacenters/{datacenterId}/volumes/{volumeId}/labels | Add a Label to Volume
*LabelApi* | [**datacenters_volumes_labels_put**](docs/LabelApi.md#datacenters_volumes_labels_put) | **PUT** /datacenters/{datacenterId}/volumes/{volumeId}/labels/{key} | Modify a Label of Volume
*LabelApi* | [**ipblocks_labels_delete**](docs/LabelApi.md#ipblocks_labels_delete) | **DELETE** /ipblocks/{ipblockId}/labels/{key} | Delete a Label from IP Block
*LabelApi* | [**ipblocks_labels_find_by_key**](docs/LabelApi.md#ipblocks_labels_find_by_key) | **GET** /ipblocks/{ipblockId}/labels/{key} | Retrieve a Label of IP Block
*LabelApi* | [**ipblocks_labels_get**](docs/LabelApi.md#ipblocks_labels_get) | **GET** /ipblocks/{ipblockId}/labels | List all Ip Block Labels
*LabelApi* | [**ipblocks_labels_post**](docs/LabelApi.md#ipblocks_labels_post) | **POST** /ipblocks/{ipblockId}/labels | Add a Label to IP Block
*LabelApi* | [**ipblocks_labels_put**](docs/LabelApi.md#ipblocks_labels_put) | **PUT** /ipblocks/{ipblockId}/labels/{key} | Modify a Label of IP Block
*LabelApi* | [**labels_find_by_labelurn**](docs/LabelApi.md#labels_find_by_labelurn) | **GET** /labels/{labelurn} | Returns the label by its URN.
*LabelApi* | [**labels_get**](docs/LabelApi.md#labels_get) | **GET** /labels | List Labels 
*LabelApi* | [**snapshots_labels_delete**](docs/LabelApi.md#snapshots_labels_delete) | **DELETE** /snapshots/{snapshotId}/labels/{key} | Delete a Label from Snapshot
*LabelApi* | [**snapshots_labels_find_by_key**](docs/LabelApi.md#snapshots_labels_find_by_key) | **GET** /snapshots/{snapshotId}/labels/{key} | Retrieve a Label of Snapshot
*LabelApi* | [**snapshots_labels_get**](docs/LabelApi.md#snapshots_labels_get) | **GET** /snapshots/{snapshotId}/labels | List all Snapshot Labels
*LabelApi* | [**snapshots_labels_post**](docs/LabelApi.md#snapshots_labels_post) | **POST** /snapshots/{snapshotId}/labels | Add a Label to Snapshot
*LabelApi* | [**snapshots_labels_put**](docs/LabelApi.md#snapshots_labels_put) | **PUT** /snapshots/{snapshotId}/labels/{key} | Modify a Label of Snapshot
*LanApi* | [**datacenters_lans_delete**](docs/LanApi.md#datacenters_lans_delete) | **DELETE** /datacenters/{datacenterId}/lans/{lanId} | Delete a Lan.
*LanApi* | [**datacenters_lans_find_by_id**](docs/LanApi.md#datacenters_lans_find_by_id) | **GET** /datacenters/{datacenterId}/lans/{lanId} | Retrieve a Lan
*LanApi* | [**datacenters_lans_get**](docs/LanApi.md#datacenters_lans_get) | **GET** /datacenters/{datacenterId}/lans | List Lans
*LanApi* | [**datacenters_lans_nics_find_by_id**](docs/LanApi.md#datacenters_lans_nics_find_by_id) | **GET** /datacenters/{datacenterId}/lans/{lanId}/nics/{nicId} | Retrieve a nic attached to lan
*LanApi* | [**datacenters_lans_nics_get**](docs/LanApi.md#datacenters_lans_nics_get) | **GET** /datacenters/{datacenterId}/lans/{lanId}/nics | List Lan Members 
*LanApi* | [**datacenters_lans_nics_post**](docs/LanApi.md#datacenters_lans_nics_post) | **POST** /datacenters/{datacenterId}/lans/{lanId}/nics | Attach a nic
*LanApi* | [**datacenters_lans_patch**](docs/LanApi.md#datacenters_lans_patch) | **PATCH** /datacenters/{datacenterId}/lans/{lanId} | Partially modify a Lan
*LanApi* | [**datacenters_lans_post**](docs/LanApi.md#datacenters_lans_post) | **POST** /datacenters/{datacenterId}/lans | Create a Lan
*LanApi* | [**datacenters_lans_put**](docs/LanApi.md#datacenters_lans_put) | **PUT** /datacenters/{datacenterId}/lans/{lanId} | Modify a Lan
*LoadBalancerApi* | [**datacenters_loadbalancers_balancednics_delete**](docs/LoadBalancerApi.md#datacenters_loadbalancers_balancednics_delete) | **DELETE** /datacenters/{datacenterId}/loadbalancers/{loadbalancerId}/balancednics/{nicId} | Detach a nic from loadbalancer
*LoadBalancerApi* | [**datacenters_loadbalancers_balancednics_find_by_nic**](docs/LoadBalancerApi.md#datacenters_loadbalancers_balancednics_find_by_nic) | **GET** /datacenters/{datacenterId}/loadbalancers/{loadbalancerId}/balancednics/{nicId} | Retrieve a nic attached to Load Balancer
*LoadBalancerApi* | [**datacenters_loadbalancers_balancednics_get**](docs/LoadBalancerApi.md#datacenters_loadbalancers_balancednics_get) | **GET** /datacenters/{datacenterId}/loadbalancers/{loadbalancerId}/balancednics | List Load Balancer Members 
*LoadBalancerApi* | [**datacenters_loadbalancers_balancednics_post**](docs/LoadBalancerApi.md#datacenters_loadbalancers_balancednics_post) | **POST** /datacenters/{datacenterId}/loadbalancers/{loadbalancerId}/balancednics | Attach a nic to Load Balancer
*LoadBalancerApi* | [**datacenters_loadbalancers_delete**](docs/LoadBalancerApi.md#datacenters_loadbalancers_delete) | **DELETE** /datacenters/{datacenterId}/loadbalancers/{loadbalancerId} | Delete a Loadbalancer.
*LoadBalancerApi* | [**datacenters_loadbalancers_find_by_id**](docs/LoadBalancerApi.md#datacenters_loadbalancers_find_by_id) | **GET** /datacenters/{datacenterId}/loadbalancers/{loadbalancerId} | Retrieve a loadbalancer
*LoadBalancerApi* | [**datacenters_loadbalancers_get**](docs/LoadBalancerApi.md#datacenters_loadbalancers_get) | **GET** /datacenters/{datacenterId}/loadbalancers | List Load Balancers
*LoadBalancerApi* | [**datacenters_loadbalancers_patch**](docs/LoadBalancerApi.md#datacenters_loadbalancers_patch) | **PATCH** /datacenters/{datacenterId}/loadbalancers/{loadbalancerId} | Partially modify a Loadbalancer
*LoadBalancerApi* | [**datacenters_loadbalancers_post**](docs/LoadBalancerApi.md#datacenters_loadbalancers_post) | **POST** /datacenters/{datacenterId}/loadbalancers | Create a Load Balancer
*LoadBalancerApi* | [**datacenters_loadbalancers_put**](docs/LoadBalancerApi.md#datacenters_loadbalancers_put) | **PUT** /datacenters/{datacenterId}/loadbalancers/{loadbalancerId} | Modify a Load Balancer
*LocationApi* | [**locations_find_by_region**](docs/LocationApi.md#locations_find_by_region) | **GET** /locations/{regionId} | List Locations within a region
*LocationApi* | [**locations_find_by_region_and_id**](docs/LocationApi.md#locations_find_by_region_and_id) | **GET** /locations/{regionId}/{locationId} | Retrieve a Location
*LocationApi* | [**locations_get**](docs/LocationApi.md#locations_get) | **GET** /locations | List Locations
*NicApi* | [**datacenters_servers_nics_delete**](docs/NicApi.md#datacenters_servers_nics_delete) | **DELETE** /datacenters/{datacenterId}/servers/{serverId}/nics/{nicId} | Delete a Nic
*NicApi* | [**datacenters_servers_nics_find_by_id**](docs/NicApi.md#datacenters_servers_nics_find_by_id) | **GET** /datacenters/{datacenterId}/servers/{serverId}/nics/{nicId} | Retrieve a Nic
*NicApi* | [**datacenters_servers_nics_firewallrules_delete**](docs/NicApi.md#datacenters_servers_nics_firewallrules_delete) | **DELETE** /datacenters/{datacenterId}/servers/{serverId}/nics/{nicId}/firewallrules/{firewallruleId} | Delete a Firewall Rule
*NicApi* | [**datacenters_servers_nics_firewallrules_find_by_id**](docs/NicApi.md#datacenters_servers_nics_firewallrules_find_by_id) | **GET** /datacenters/{datacenterId}/servers/{serverId}/nics/{nicId}/firewallrules/{firewallruleId} | Retrieve a Firewall Rule
*NicApi* | [**datacenters_servers_nics_firewallrules_get**](docs/NicApi.md#datacenters_servers_nics_firewallrules_get) | **GET** /datacenters/{datacenterId}/servers/{serverId}/nics/{nicId}/firewallrules | List Firewall Rules 
*NicApi* | [**datacenters_servers_nics_firewallrules_patch**](docs/NicApi.md#datacenters_servers_nics_firewallrules_patch) | **PATCH** /datacenters/{datacenterId}/servers/{serverId}/nics/{nicId}/firewallrules/{firewallruleId} | Partially modify a Firewall Rule
*NicApi* | [**datacenters_servers_nics_firewallrules_post**](docs/NicApi.md#datacenters_servers_nics_firewallrules_post) | **POST** /datacenters/{datacenterId}/servers/{serverId}/nics/{nicId}/firewallrules | Create a Firewall Rule
*NicApi* | [**datacenters_servers_nics_firewallrules_put**](docs/NicApi.md#datacenters_servers_nics_firewallrules_put) | **PUT** /datacenters/{datacenterId}/servers/{serverId}/nics/{nicId}/firewallrules/{firewallruleId} | Modify a Firewall Rule
*NicApi* | [**datacenters_servers_nics_get**](docs/NicApi.md#datacenters_servers_nics_get) | **GET** /datacenters/{datacenterId}/servers/{serverId}/nics | List Nics 
*NicApi* | [**datacenters_servers_nics_patch**](docs/NicApi.md#datacenters_servers_nics_patch) | **PATCH** /datacenters/{datacenterId}/servers/{serverId}/nics/{nicId} | Partially modify a Nic
*NicApi* | [**datacenters_servers_nics_post**](docs/NicApi.md#datacenters_servers_nics_post) | **POST** /datacenters/{datacenterId}/servers/{serverId}/nics | Create a Nic
*NicApi* | [**datacenters_servers_nics_put**](docs/NicApi.md#datacenters_servers_nics_put) | **PUT** /datacenters/{datacenterId}/servers/{serverId}/nics/{nicId} | Modify a Nic
*PrivateCrossConnectApi* | [**pccs_delete**](docs/PrivateCrossConnectApi.md#pccs_delete) | **DELETE** /pccs/{pccId} | Delete a Private Cross-Connect
*PrivateCrossConnectApi* | [**pccs_find_by_id**](docs/PrivateCrossConnectApi.md#pccs_find_by_id) | **GET** /pccs/{pccId} | Retrieve a Private Cross-Connect
*PrivateCrossConnectApi* | [**pccs_get**](docs/PrivateCrossConnectApi.md#pccs_get) | **GET** /pccs | List Private Cross-Connects 
*PrivateCrossConnectApi* | [**pccs_patch**](docs/PrivateCrossConnectApi.md#pccs_patch) | **PATCH** /pccs/{pccId} | Partially modify a private cross-connect
*PrivateCrossConnectApi* | [**pccs_post**](docs/PrivateCrossConnectApi.md#pccs_post) | **POST** /pccs | Create a Private Cross-Connect
*RequestApi* | [**requests_find_by_id**](docs/RequestApi.md#requests_find_by_id) | **GET** /requests/{requestId} | Retrieve a Request
*RequestApi* | [**requests_get**](docs/RequestApi.md#requests_get) | **GET** /requests | List Requests
*RequestApi* | [**requests_status_get**](docs/RequestApi.md#requests_status_get) | **GET** /requests/{requestId}/status | Retrieve Request Status
*ServerApi* | [**datacenters_servers_cdroms_delete**](docs/ServerApi.md#datacenters_servers_cdroms_delete) | **DELETE** /datacenters/{datacenterId}/servers/{serverId}/cdroms/{cdromId} | Detach a CD-ROM
*ServerApi* | [**datacenters_servers_cdroms_find_by_id**](docs/ServerApi.md#datacenters_servers_cdroms_find_by_id) | **GET** /datacenters/{datacenterId}/servers/{serverId}/cdroms/{cdromId} | Retrieve an attached CD-ROM
*ServerApi* | [**datacenters_servers_cdroms_get**](docs/ServerApi.md#datacenters_servers_cdroms_get) | **GET** /datacenters/{datacenterId}/servers/{serverId}/cdroms | List attached CD-ROMs 
*ServerApi* | [**datacenters_servers_cdroms_post**](docs/ServerApi.md#datacenters_servers_cdroms_post) | **POST** /datacenters/{datacenterId}/servers/{serverId}/cdroms | Attach a CD-ROM
*ServerApi* | [**datacenters_servers_delete**](docs/ServerApi.md#datacenters_servers_delete) | **DELETE** /datacenters/{datacenterId}/servers/{serverId} | Delete a Server
*ServerApi* | [**datacenters_servers_find_by_id**](docs/ServerApi.md#datacenters_servers_find_by_id) | **GET** /datacenters/{datacenterId}/servers/{serverId} | Retrieve a Server
*ServerApi* | [**datacenters_servers_get**](docs/ServerApi.md#datacenters_servers_get) | **GET** /datacenters/{datacenterId}/servers | List Servers 
*ServerApi* | [**datacenters_servers_patch**](docs/ServerApi.md#datacenters_servers_patch) | **PATCH** /datacenters/{datacenterId}/servers/{serverId} | Partially modify a Server
*ServerApi* | [**datacenters_servers_post**](docs/ServerApi.md#datacenters_servers_post) | **POST** /datacenters/{datacenterId}/servers | Create a Server
*ServerApi* | [**datacenters_servers_put**](docs/ServerApi.md#datacenters_servers_put) | **PUT** /datacenters/{datacenterId}/servers/{serverId} | Modify a Server
*ServerApi* | [**datacenters_servers_reboot_post**](docs/ServerApi.md#datacenters_servers_reboot_post) | **POST** /datacenters/{datacenterId}/servers/{serverId}/reboot | Reboot a Server
*ServerApi* | [**datacenters_servers_start_post**](docs/ServerApi.md#datacenters_servers_start_post) | **POST** /datacenters/{datacenterId}/servers/{serverId}/start | Start a Server
*ServerApi* | [**datacenters_servers_stop_post**](docs/ServerApi.md#datacenters_servers_stop_post) | **POST** /datacenters/{datacenterId}/servers/{serverId}/stop | Stop a Server
*ServerApi* | [**datacenters_servers_upgrade_post**](docs/ServerApi.md#datacenters_servers_upgrade_post) | **POST** /datacenters/{datacenterId}/servers/{serverId}/upgrade | Upgrade a Server
*ServerApi* | [**datacenters_servers_volumes_delete**](docs/ServerApi.md#datacenters_servers_volumes_delete) | **DELETE** /datacenters/{datacenterId}/servers/{serverId}/volumes/{volumeId} | Detach a volume
*ServerApi* | [**datacenters_servers_volumes_find_by_id**](docs/ServerApi.md#datacenters_servers_volumes_find_by_id) | **GET** /datacenters/{datacenterId}/servers/{serverId}/volumes/{volumeId} | Retrieve an attached volume
*ServerApi* | [**datacenters_servers_volumes_get**](docs/ServerApi.md#datacenters_servers_volumes_get) | **GET** /datacenters/{datacenterId}/servers/{serverId}/volumes | List Attached Volumes
*ServerApi* | [**datacenters_servers_volumes_post**](docs/ServerApi.md#datacenters_servers_volumes_post) | **POST** /datacenters/{datacenterId}/servers/{serverId}/volumes | Attach a volume
*SnapshotApi* | [**snapshots_delete**](docs/SnapshotApi.md#snapshots_delete) | **DELETE** /snapshots/{snapshotId} | Delete a Snapshot
*SnapshotApi* | [**snapshots_find_by_id**](docs/SnapshotApi.md#snapshots_find_by_id) | **GET** /snapshots/{snapshotId} | Retrieve a Snapshot by its uuid.
*SnapshotApi* | [**snapshots_get**](docs/SnapshotApi.md#snapshots_get) | **GET** /snapshots | List Snapshots 
*SnapshotApi* | [**snapshots_patch**](docs/SnapshotApi.md#snapshots_patch) | **PATCH** /snapshots/{snapshotId} | Partially modify a Snapshot
*SnapshotApi* | [**snapshots_put**](docs/SnapshotApi.md#snapshots_put) | **PUT** /snapshots/{snapshotId} | Modify a Snapshot
*UserManagementApi* | [**um_groups_delete**](docs/UserManagementApi.md#um_groups_delete) | **DELETE** /um/groups/{groupId} | Delete a Group
*UserManagementApi* | [**um_groups_find_by_id**](docs/UserManagementApi.md#um_groups_find_by_id) | **GET** /um/groups/{groupId} | Retrieve a Group
*UserManagementApi* | [**um_groups_get**](docs/UserManagementApi.md#um_groups_get) | **GET** /um/groups | List All Groups.
*UserManagementApi* | [**um_groups_post**](docs/UserManagementApi.md#um_groups_post) | **POST** /um/groups | Create a Group
*UserManagementApi* | [**um_groups_put**](docs/UserManagementApi.md#um_groups_put) | **PUT** /um/groups/{groupId} | Modify a group
*UserManagementApi* | [**um_groups_resources_get**](docs/UserManagementApi.md#um_groups_resources_get) | **GET** /um/groups/{groupId}/resources | Retrieve resources assigned to a group
*UserManagementApi* | [**um_groups_shares_delete**](docs/UserManagementApi.md#um_groups_shares_delete) | **DELETE** /um/groups/{groupId}/shares/{resourceId} | Remove a resource from a group
*UserManagementApi* | [**um_groups_shares_find_by_resource**](docs/UserManagementApi.md#um_groups_shares_find_by_resource) | **GET** /um/groups/{groupId}/shares/{resourceId} | Retrieve a group share
*UserManagementApi* | [**um_groups_shares_get**](docs/UserManagementApi.md#um_groups_shares_get) | **GET** /um/groups/{groupId}/shares | List Group Shares 
*UserManagementApi* | [**um_groups_shares_post**](docs/UserManagementApi.md#um_groups_shares_post) | **POST** /um/groups/{groupId}/shares/{resourceId} | Add a resource to a group
*UserManagementApi* | [**um_groups_shares_put**](docs/UserManagementApi.md#um_groups_shares_put) | **PUT** /um/groups/{groupId}/shares/{resourceId} | Modify resource permissions of a group
*UserManagementApi* | [**um_groups_users_delete**](docs/UserManagementApi.md#um_groups_users_delete) | **DELETE** /um/groups/{groupId}/users/{userId} | Remove a user from a group
*UserManagementApi* | [**um_groups_users_get**](docs/UserManagementApi.md#um_groups_users_get) | **GET** /um/groups/{groupId}/users | List Group Members 
*UserManagementApi* | [**um_groups_users_post**](docs/UserManagementApi.md#um_groups_users_post) | **POST** /um/groups/{groupId}/users | Add a user to a group
*UserManagementApi* | [**um_resources_find_by_type**](docs/UserManagementApi.md#um_resources_find_by_type) | **GET** /um/resources/{resourceType} | Retrieve a list of Resources by type.
*UserManagementApi* | [**um_resources_find_by_type_and_id**](docs/UserManagementApi.md#um_resources_find_by_type_and_id) | **GET** /um/resources/{resourceType}/{resourceId} | Retrieve a Resource by type.
*UserManagementApi* | [**um_resources_get**](docs/UserManagementApi.md#um_resources_get) | **GET** /um/resources | List All Resources.
*UserManagementApi* | [**um_users_delete**](docs/UserManagementApi.md#um_users_delete) | **DELETE** /um/users/{userId} | Delete a User
*UserManagementApi* | [**um_users_find_by_id**](docs/UserManagementApi.md#um_users_find_by_id) | **GET** /um/users/{userId} | Retrieve a User
*UserManagementApi* | [**um_users_get**](docs/UserManagementApi.md#um_users_get) | **GET** /um/users | List all Users 
*UserManagementApi* | [**um_users_groups_get**](docs/UserManagementApi.md#um_users_groups_get) | **GET** /um/users/{userId}/groups | Retrieve a User&#39;s group resources
*UserManagementApi* | [**um_users_owns_get**](docs/UserManagementApi.md#um_users_owns_get) | **GET** /um/users/{userId}/owns | Retrieve a User&#39;s own resources
*UserManagementApi* | [**um_users_post**](docs/UserManagementApi.md#um_users_post) | **POST** /um/users | Create a user
*UserManagementApi* | [**um_users_put**](docs/UserManagementApi.md#um_users_put) | **PUT** /um/users/{userId} | Modify a user
*UserManagementApi* | [**um_users_s3keys_delete**](docs/UserManagementApi.md#um_users_s3keys_delete) | **DELETE** /um/users/{userId}/s3keys/{keyId} | Delete a S3 key
*UserManagementApi* | [**um_users_s3keys_find_by_key**](docs/UserManagementApi.md#um_users_s3keys_find_by_key) | **GET** /um/users/{userId}/s3keys/{keyId} | Retrieve given S3 key belonging to the given User
*UserManagementApi* | [**um_users_s3keys_get**](docs/UserManagementApi.md#um_users_s3keys_get) | **GET** /um/users/{userId}/s3keys | Retrieve a User&#39;s S3 keys
*UserManagementApi* | [**um_users_s3keys_post**](docs/UserManagementApi.md#um_users_s3keys_post) | **POST** /um/users/{userId}/s3keys | Create a S3 key for the given user
*UserManagementApi* | [**um_users_s3keys_put**](docs/UserManagementApi.md#um_users_s3keys_put) | **PUT** /um/users/{userId}/s3keys/{keyId} | Modify a S3 key having the given key id
*UserManagementApi* | [**um_users_s3ssourl_get**](docs/UserManagementApi.md#um_users_s3ssourl_get) | **GET** /um/users/{userId}/s3ssourl | Retrieve S3 object storage single signon URL for the given user
*VolumeApi* | [**datacenters_volumes_create_snapshot_post**](docs/VolumeApi.md#datacenters_volumes_create_snapshot_post) | **POST** /datacenters/{datacenterId}/volumes/{volumeId}/create-snapshot | Create Volume Snapshot
*VolumeApi* | [**datacenters_volumes_delete**](docs/VolumeApi.md#datacenters_volumes_delete) | **DELETE** /datacenters/{datacenterId}/volumes/{volumeId} | Delete a Volume
*VolumeApi* | [**datacenters_volumes_find_by_id**](docs/VolumeApi.md#datacenters_volumes_find_by_id) | **GET** /datacenters/{datacenterId}/volumes/{volumeId} | Retrieve a Volume
*VolumeApi* | [**datacenters_volumes_get**](docs/VolumeApi.md#datacenters_volumes_get) | **GET** /datacenters/{datacenterId}/volumes | List Volumes 
*VolumeApi* | [**datacenters_volumes_patch**](docs/VolumeApi.md#datacenters_volumes_patch) | **PATCH** /datacenters/{datacenterId}/volumes/{volumeId} | Partially modify a Volume
*VolumeApi* | [**datacenters_volumes_post**](docs/VolumeApi.md#datacenters_volumes_post) | **POST** /datacenters/{datacenterId}/volumes | Create a Volume
*VolumeApi* | [**datacenters_volumes_put**](docs/VolumeApi.md#datacenters_volumes_put) | **PUT** /datacenters/{datacenterId}/volumes/{volumeId} | Modify a Volume
*VolumeApi* | [**datacenters_volumes_restore_snapshot_post**](docs/VolumeApi.md#datacenters_volumes_restore_snapshot_post) | **POST** /datacenters/{datacenterId}/volumes/{volumeId}/restore-snapshot | Restore Volume Snapshot


## Documentation For Models

 - [AttachedVolumes](docs/AttachedVolumes.md)
 - [BackupUnit](docs/BackupUnit.md)
 - [BackupUnitProperties](docs/BackupUnitProperties.md)
 - [BackupUnitSSO](docs/BackupUnitSSO.md)
 - [BackupUnits](docs/BackupUnits.md)
 - [BalancedNics](docs/BalancedNics.md)
 - [Cdroms](docs/Cdroms.md)
 - [ConnectableDatacenter](docs/ConnectableDatacenter.md)
 - [Contract](docs/Contract.md)
 - [ContractProperties](docs/ContractProperties.md)
 - [Datacenter](docs/Datacenter.md)
 - [DatacenterElementMetadata](docs/DatacenterElementMetadata.md)
 - [DatacenterEntities](docs/DatacenterEntities.md)
 - [DatacenterProperties](docs/DatacenterProperties.md)
 - [Datacenters](docs/Datacenters.md)
 - [Error](docs/Error.md)
 - [ErrorMessage](docs/ErrorMessage.md)
 - [FirewallRule](docs/FirewallRule.md)
 - [FirewallRules](docs/FirewallRules.md)
 - [FirewallruleProperties](docs/FirewallruleProperties.md)
 - [Group](docs/Group.md)
 - [GroupEntities](docs/GroupEntities.md)
 - [GroupMembers](docs/GroupMembers.md)
 - [GroupProperties](docs/GroupProperties.md)
 - [GroupShare](docs/GroupShare.md)
 - [GroupShareProperties](docs/GroupShareProperties.md)
 - [GroupShares](docs/GroupShares.md)
 - [GroupUsers](docs/GroupUsers.md)
 - [Groups](docs/Groups.md)
 - [IPFailover](docs/IPFailover.md)
 - [Image](docs/Image.md)
 - [ImageProperties](docs/ImageProperties.md)
 - [Images](docs/Images.md)
 - [Info](docs/Info.md)
 - [IpBlock](docs/IpBlock.md)
 - [IpBlockProperties](docs/IpBlockProperties.md)
 - [IpBlocks](docs/IpBlocks.md)
 - [IpConsumer](docs/IpConsumer.md)
 - [KubernetesAutoScaling](docs/KubernetesAutoScaling.md)
 - [KubernetesCluster](docs/KubernetesCluster.md)
 - [KubernetesClusterEntities](docs/KubernetesClusterEntities.md)
 - [KubernetesClusterProperties](docs/KubernetesClusterProperties.md)
 - [KubernetesClusters](docs/KubernetesClusters.md)
 - [KubernetesConfig](docs/KubernetesConfig.md)
 - [KubernetesConfigProperties](docs/KubernetesConfigProperties.md)
 - [KubernetesMaintenanceWindow](docs/KubernetesMaintenanceWindow.md)
 - [KubernetesNode](docs/KubernetesNode.md)
 - [KubernetesNodeMetadata](docs/KubernetesNodeMetadata.md)
 - [KubernetesNodePool](docs/KubernetesNodePool.md)
 - [KubernetesNodePoolAnnotation](docs/KubernetesNodePoolAnnotation.md)
 - [KubernetesNodePoolForPut](docs/KubernetesNodePoolForPut.md)
 - [KubernetesNodePoolLabel](docs/KubernetesNodePoolLabel.md)
 - [KubernetesNodePoolLan](docs/KubernetesNodePoolLan.md)
 - [KubernetesNodePoolProperties](docs/KubernetesNodePoolProperties.md)
 - [KubernetesNodePoolPropertiesForPut](docs/KubernetesNodePoolPropertiesForPut.md)
 - [KubernetesNodePools](docs/KubernetesNodePools.md)
 - [KubernetesNodeProperties](docs/KubernetesNodeProperties.md)
 - [KubernetesNodes](docs/KubernetesNodes.md)
 - [Label](docs/Label.md)
 - [LabelProperties](docs/LabelProperties.md)
 - [LabelResource](docs/LabelResource.md)
 - [LabelResourceProperties](docs/LabelResourceProperties.md)
 - [LabelResources](docs/LabelResources.md)
 - [Labels](docs/Labels.md)
 - [Lan](docs/Lan.md)
 - [LanEntities](docs/LanEntities.md)
 - [LanNics](docs/LanNics.md)
 - [LanPost](docs/LanPost.md)
 - [LanProperties](docs/LanProperties.md)
 - [LanPropertiesPost](docs/LanPropertiesPost.md)
 - [Lans](docs/Lans.md)
 - [Loadbalancer](docs/Loadbalancer.md)
 - [LoadbalancerEntities](docs/LoadbalancerEntities.md)
 - [LoadbalancerProperties](docs/LoadbalancerProperties.md)
 - [Loadbalancers](docs/Loadbalancers.md)
 - [Location](docs/Location.md)
 - [LocationProperties](docs/LocationProperties.md)
 - [Locations](docs/Locations.md)
 - [Nic](docs/Nic.md)
 - [NicEntities](docs/NicEntities.md)
 - [NicProperties](docs/NicProperties.md)
 - [Nics](docs/Nics.md)
 - [NoStateMetaData](docs/NoStateMetaData.md)
 - [Peer](docs/Peer.md)
 - [PrivateCrossConnect](docs/PrivateCrossConnect.md)
 - [PrivateCrossConnectProperties](docs/PrivateCrossConnectProperties.md)
 - [PrivateCrossConnects](docs/PrivateCrossConnects.md)
 - [Request](docs/Request.md)
 - [RequestMetadata](docs/RequestMetadata.md)
 - [RequestProperties](docs/RequestProperties.md)
 - [RequestStatus](docs/RequestStatus.md)
 - [RequestStatusMetadata](docs/RequestStatusMetadata.md)
 - [RequestTarget](docs/RequestTarget.md)
 - [Requests](docs/Requests.md)
 - [Resource](docs/Resource.md)
 - [ResourceEntities](docs/ResourceEntities.md)
 - [ResourceGroups](docs/ResourceGroups.md)
 - [ResourceLimits](docs/ResourceLimits.md)
 - [ResourceProperties](docs/ResourceProperties.md)
 - [ResourceReference](docs/ResourceReference.md)
 - [Resources](docs/Resources.md)
 - [ResourcesUsers](docs/ResourcesUsers.md)
 - [S3Key](docs/S3Key.md)
 - [S3KeyMetadata](docs/S3KeyMetadata.md)
 - [S3KeyProperties](docs/S3KeyProperties.md)
 - [S3Keys](docs/S3Keys.md)
 - [S3ObjectStorageSSO](docs/S3ObjectStorageSSO.md)
 - [Server](docs/Server.md)
 - [ServerEntities](docs/ServerEntities.md)
 - [ServerProperties](docs/ServerProperties.md)
 - [Servers](docs/Servers.md)
 - [Snapshot](docs/Snapshot.md)
 - [SnapshotProperties](docs/SnapshotProperties.md)
 - [Snapshots](docs/Snapshots.md)
 - [Type](docs/Type.md)
 - [User](docs/User.md)
 - [UserMetadata](docs/UserMetadata.md)
 - [UserProperties](docs/UserProperties.md)
 - [Users](docs/Users.md)
 - [UsersEntities](docs/UsersEntities.md)
 - [Volume](docs/Volume.md)
 - [VolumeProperties](docs/VolumeProperties.md)
 - [Volumes](docs/Volumes.md)


## Documentation For Authorization


## Basic Authentication

- **Type**: HTTP basic authentication


## Token Authentication

- **Type**: API key
- **API key parameter name**: Authorization
- **Location**: HTTP header


## Author




